@@ -1,7 +1,7 @@
 use strict; use warnings;
 package Inline;
 
-our $VERSION = '0.80_02';
+our $VERSION = '0.80_03';
 
 use Inline::denter;
 use Config;
@@ -829,7 +829,7 @@ sub create_config_file {
         # Inline::CPP (and perhaps other Inline modules) will fail because P::RD isn't found.
         my @_inc = map { "-I$_" }
        ($inline,
-        grep {(-d File::Spec->catdir($_,"Inline") or -d File::Spec->catdir($_,"auto","Inline") or -e File::Spec->catdir($_,"Parse/RecDescent.pm"))} @INC);
+        grep {(-d File::Spec->catdir($_,"Inline") or -d File::Spec->catdir($_,"auto","Inline") or -e File::Spec->catdir($_,"Win32/Mutex.pm") or -e File::Spec->catdir($_,"Parse/RecDescent.pm"))} @INC);
        system $perl, @_inc, "-MInline=_CONFIG_", "-e1", "$dir"
           and croak M20_config_creation_failed($dir);
         return;
